﻿using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using Telerik.Web.UI;

namespace AjaxVisualWebPart.AjaxVisualWebPart
{
    [ToolboxItemAttribute(false)]
    public class AjaxVisualWebPart : WebPart
    {
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            SetUpAjaxManagerOnPage();

            EnsureChildControls();
        }

        // Visual Studio might automatically update this path when you change the Visual Web Part project item.
        private const string _ascxPath = @"~/_CONTROLTEMPLATES/AjaxVisualWebPart/AjaxVisualWebPart/AjaxVisualWebPartUserControl.ascx";

        protected override void CreateChildControls()
        {
            Control control = Page.LoadControl(_ascxPath);

            RadGrid grid = control.FindControl("RadGrid1") as RadGrid;
            RadAjaxLoadingPanel loadingPanel = control.FindControl("RadAjaxLoadingPanel1") as RadAjaxLoadingPanel;
            RadTabStrip tabStrip = control.FindControl("RadTabStrip1") as RadTabStrip;
            RadMultiPage multiPage = control.FindControl("RadMultiPage1") as RadMultiPage;

  

            if (tabStrip != null)
            {
                AjaxSetting ajaxSetting = new AjaxSetting();

                ajaxSetting.AjaxControlID = tabStrip.ID;
                ajaxSetting.UpdatedControls.Add(new AjaxUpdatedControl(tabStrip.ID, loadingPanel.ID));

                AjaxManager.AjaxSettings.Add(ajaxSetting);
            }

            if (multiPage != null)
            {
                AjaxSetting ajaxSetting = new AjaxSetting();

                ajaxSetting.AjaxControlID = multiPage.ID;
                ajaxSetting.UpdatedControls.Add(new AjaxUpdatedControl(multiPage.ID, loadingPanel.ID));

                AjaxManager.AjaxSettings.Add(ajaxSetting);
            }

            Controls.Add(control);
        }

        protected void SetUpAjaxManagerOnPage()
        {
            RadAjaxManager currentAjaxManager = RadAjaxManager.GetCurrent(Page);

            if (currentAjaxManager == null)
            {
                Page.Form.Controls.AddAt(0, AjaxManager);
                Page.Items.Add(typeof(RadAjaxManager), AjaxManager);
            }
        }

        private RadAjaxManager _ajaxManager;
        protected virtual RadAjaxManager AjaxManager
        {
            get
            {
                if (_ajaxManager == null)
                {
                    _ajaxManager = RadAjaxManager.GetCurrent(Page);

                    if (_ajaxManager == null)
                    {
                        _ajaxManager = new RadAjaxManager() { ID = "RadAjaxManager1" };
                    }
                }

                return _ajaxManager;
            }
        }
    }
}
